/*
	Copyright Adil Qureshi - 1997
	This code is part of gpsys Release 1.1
	and is released for non-commercial use only.
	Questions, comments etc should be forwarded to :-

		Adil Qureshi
		University College London,
		Department of Computer Science,
		Gower St,
		London WC1E 6BT, UK.
		Tel: +44 (0)171 380 7777 x4436
		Fax: +44 (0)171 387 1397
		email: A.Qureshi@cs.ucl.ac.uk
		URL : http://www.cs.ucl.ac.uk/staff/A.Qureshi/
*/

package gpsys;

import java.util.Hashtable;

/**
 * A Table that maps a given Type to an array of Terminals returning that type.
 *
 * @version		1.1, 30th June '97
 * @author 	<a href="mailto:A.Qureshi@cs.ucl.ac.uk">Adil Qureshi</a>
 *			<address>Department of Computer Science,</address>
 *			<address>University College London,</address>
 *			<address>Gower St,</address>
 *			<address>London WC1E 6BT,</address>
 *			<address>UK.</address>
 */
public class TypeToTerminalsTable implements java.io.Serializable {
	Hashtable theTable;

	/**
	* Creates a table of the specified initial capacity.  The table is
	* automatically increased in size if the number of entries exceed 50% of
	* the initial capacity.
	*
	* @param initialCapacity	The initial capacity of the table.
	*/
	public TypeToTerminalsTable(int initialCapacity) {
		theTable = new Hashtable(initialCapacity, 0.5f);
	}

	/**
	* Get all the Terminals that return the specified type.
	*
	* @param t	The return type of the Terminals.
	*/
	public final Terminal[] get(Type t) {
		return (Terminal[]) theTable.get(t);
	}

	/**
	* Put the specified Terminals array in the table.  The Terminals all
	* return the type t which is the key to be used for retrieval via get().
	*
	* @param t			The return type of the Terminals.
	* @param functions	The array of Terminals return the above type.
	*/
	public final void put(Type t, Terminal[] terminals) {
		theTable.put(t, terminals);
	}
}
