/*
	Copyright Adil Qureshi - 1997
	This code is part of gpsys Release 1.1
	and is released for non-commercial use only.
	Questions, comments etc should be forwarded to :-

		Adil Qureshi
		University College London,
		Department of Computer Science,
		Gower St,
		London WC1E 6BT, UK.
		Tel: +44 (0)171 380 7777 x4436
		Fax: +44 (0)171 387 1397
		email: A.Qureshi@cs.ucl.ac.uk
		URL : http://www.cs.ucl.ac.uk/staff/A.Qureshi/
*/

package gpsys.primitives;

import gpsys.*;


/**
 * <pre>
 *	BOOLEAN and(BOOLEAN b1, BOOLEAN b2)
 * </pre>
 *
 * And is a boolean function that returns the logical "and" of both arguments.
 * Note that And is NOT lazy, so that both arguments are still evaluated even
 * if the first argument is False.
 *
 * @see			gpsys.Type
 * @see			gpsys.Primitive
 * @see			gpsys.Function
 *
 * @version     1.1, 30th June '97
 * @author 	<a href="mailto:A.Qureshi@cs.ucl.ac.uk">Adil Qureshi</a>
 *			<address>Department of Computer Science,</address>
 *			<address>University College London,</address>
 *			<address>Gower St,</address>
 *			<address>London WC1E 6BT,</address>
 *			<address>UK.</address>
 */
public class And extends Function {

	/**
	* Construct an instance of the And Function.  The And Function is of
	* BOOLEAN Type and is hence typed accordingly.
	*/
	public And() {
		type = Type.BOOLEAN;
		argTypes = new Type[2];
		argTypes[0] = type;
		argTypes[1] = type;
	}

	/**
	* Perform the logical And of both arguments and return the result.
	*
	* @param i	The individual being evaluated.
	* @param arguments	The Gene trees representing the arguments to be Anded.
	* @return A boolean representing the logical and of the arguments.
	* @exception	EvaluationException	If there is an evaluation failure.
	*/
	public final boolean evaluateBoolean(Individual i, Gene[] arguments)
	throws EvaluationException {
		return
			arguments[0].evaluateBoolean(i) &
			arguments[1].evaluateBoolean(i);
	}

	/**
	* Creates an instance of this And Function.
	*
	* @return A reference to this object.
	*/
	public final Primitive instance() {
		return this;
	}

	/**
	* Returns a String representation of this Function.
	*
	* @return A String containing the name of the Function.
	*/
	public String toString() {
		return "And";
	}
}
