/*
	Copyright Adil Qureshi - 1997
	This code is part of gpsys Release 1.1
	and is released for non-commercial use only.
	Questions, comments etc should be forwarded to :-

		Adil Qureshi
		University College London,
		Department of Computer Science,
		Gower St,
		London WC1E 6BT, UK.
		Tel: +44 (0)171 380 7777 x4436
		Fax: +44 (0)171 387 1397
		email: A.Qureshi@cs.ucl.ac.uk
		URL : http://www.cs.ucl.ac.uk/staff/A.Qureshi/
*/

package gpsys.primitives;

import gpsys.*;

/**
 * <pre>
 *	SHORT XShort
 * </pre>
 *
 * XShort is a Terminal representing a variable of Type SHORT.
 *
 * @see			gpsys.Type
 * @see			gpsys.Primitive
 * @see			gpsys.Terminal
 *
 * @version     1.1, 30th June '97
 * @author 	<a href="mailto:A.Qureshi@cs.ucl.ac.uk">Adil Qureshi</a>
 *			<address>Department of Computer Science,</address>
 *			<address>University College London,</address>
 *			<address>Gower St,</address>
 *			<address>London WC1E 6BT,</address>
 *			<address>UK.</address>
 */
public class XShort extends Terminal {
	/**
	 * Holds the value of the variable.
	 */
	short svalue;

	/**
	 * Construct a new variable.
	 */
	public XShort() {
		this.type = Type.SHORT;
	}

	/**
	 * Evaluates the variable, which returns its value.
	 *
	 * @param	i	The variable being evaluated.
	 * @return	A short which is the value of the variable.
	 * @exception	EvaluationException	If there is an evaluation failure.
	 */
	public final short evaluateShort(Individual i)
	throws EvaluationException {
		return svalue;
	}

	/**
	 * Sets the variable to the specified value.
	 *
	 * @param value	The value to be assigned to the variable.
	 */
	public final void set(short value) {
		svalue = value;
	}

	/**
	 * Creates a copy of this Terminal.
	 *
	 * @return	Actaully a reference to the same Terminal since there is no
	 *			change in instance variables required.
	 */
	public final Primitive instance() {
		return this;
	}

	/**
	 * Creates a String representing this Terminal.
	 *
	 * @return A String containing the name of this Terminal.
	 */
	public String toString() {
		return "XShort";
	}
}
